==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QIconDragEvent_shell.cpp <==
#include "QIconDragEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QIconDragEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QIconDragEvent")
    QIconDragEvent *_ptr = reinterpret_cast<QIconDragEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QIconDragEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QIconDragEvent_shell) ); }

jmethodID QIconDragEvent_shell::__shell_javaMethod(int pos) const { return QIconDragEvent_shell::__shell()->javaMethod(typeid(QIconDragEvent), pos); }

// emitting (writeShellConstructor)
QIconDragEvent_shell::QIconDragEvent_shell()
    : QIconDragEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QIconDragEvent::QIconDragEvent_shell()", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->constructed(typeid(QIconDragEvent));
}

QIconDragEvent_shell::QIconDragEvent_shell(const QIconDragEvent& arg__1)
    : QIconDragEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QIconDragEvent::QIconDragEvent_shell(const QIconDragEvent& arg__1)", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->constructed(typeid(QIconDragEvent));
}

// emitting (writeShellDestructor)
QIconDragEvent_shell::~QIconDragEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QIconDragEvent::~QIconDragEvent()", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->destructed(typeid(QIconDragEvent));
}

void QIconDragEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QIconDragEvent_shell*>(ptr)->QIconDragEvent_shell::__shell()->tryDeleteShell(typeid(QIconDragEvent));
}

// emitting Virtual overrides (virtualFunctions)
QIconDragEvent* QIconDragEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QIconDragEvent::clone()const", QIconDragEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QIconDragEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QIconDragEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QIconDragEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QIconDragEvent_shell::__shell()->warnForMethod("QIconDragEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QIconDragEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QIconDragEvent::clone();
        }
    }else{
        return QIconDragEvent::clone();
    }
}

void QIconDragEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QIconDragEvent::", QIconDragEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QIconDragEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QIconDragEvent_shell::__shell()->warnForMethod("QIconDragEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QIconDragEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QIconDragEvent_access::__qt_assign_cref_QIconDragEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QIconDragEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QIconDragEvent>(__jni_env, other0);
    QIconDragEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QIconDragEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QIconDragEvent* __qt_return_value = QIconDragEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QIconDragEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QIconDragEvent()
void __qt_construct_QIconDragEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIconDragEvent()")
    Q_UNUSED(__java_arguments)
    QIconDragEvent *__qt_this = new(__qtjambi_ptr) QIconDragEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QIconDragEvent(QIconDragEvent)
void __qt_construct_QIconDragEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIconDragEvent(QIconDragEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QIconDragEvent& __qt_arg__1 = qtjambi_cast<const QIconDragEvent& >(__jni_env, arg__1);
    QIconDragEvent *__qt_this = new(__qtjambi_ptr) QIconDragEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QIconDragEvent_shell
void __qt_destruct_QIconDragEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QIconDragEvent")
    reinterpret_cast<QIconDragEvent_shell*>(ptr)->~QIconDragEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QIconDragEvent::QIconDragEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_initialize_1native__Lio_qt_gui_QIconDragEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIconDragEvent::QIconDragEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIconDragEvent_0, sizeof(QIconDragEvent_shell), typeid(QIconDragEvent), true, &deleter_QIconDragEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QIconDragEvent::QIconDragEvent(QIconDragEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_initialize_1native__Lio_qt_gui_QIconDragEvent_2Lio_qt_gui_QIconDragEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIconDragEvent::QIconDragEvent(QIconDragEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIconDragEvent_1, sizeof(QIconDragEvent_shell), typeid(QIconDragEvent), true, &deleter_QIconDragEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QIconDragEvent::operator=(QIconDragEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_assign_1native_1cref_1QIconDragEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QIconDragEvent *__qt_this = QtJambiAPI::objectFromNativeId<QIconDragEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QIconDragEvent::operator=(QIconDragEvent)", __qt_this)
        static_cast<QIconDragEvent_access*>(__qt_this)->__qt_assign_cref_QIconDragEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QIconDragEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QIconDragEvent *__qt_this = QtJambiAPI::objectFromNativeId<QIconDragEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QIconDragEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QIconDragEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QIconDragEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QIconDragEvent>("QIconDragEvent", "io/qt/gui/QIconDragEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QIconDragEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QIconDragEvent, {
        ConstructorInfo(&__qt_construct_QIconDragEvent_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QIconDragEvent_1, "Lio/qt/gui/QIconDragEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QIconDragEvent);
    registerSizeOfShell(typeId, sizeof(QIconDragEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QIconDragEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QIconDragEvent_shell.cpp <==
#include "QIconDragEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QIconDragEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QIconDragEvent")
    QIconDragEvent *_ptr = reinterpret_cast<QIconDragEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QIconDragEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QIconDragEvent_shell) ); }

jmethodID QIconDragEvent_shell::__shell_javaMethod(int pos) const { return QIconDragEvent_shell::__shell()->javaMethod(typeid(QIconDragEvent), pos); }

// emitting (writeShellConstructor)
QIconDragEvent_shell::QIconDragEvent_shell()
    : QIconDragEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QIconDragEvent::QIconDragEvent_shell()", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->constructed(typeid(QIconDragEvent));
}

QIconDragEvent_shell::QIconDragEvent_shell(const QIconDragEvent& arg__1)
    : QIconDragEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QIconDragEvent::QIconDragEvent_shell(const QIconDragEvent& arg__1)", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->constructed(typeid(QIconDragEvent));
}

// emitting (writeShellDestructor)
QIconDragEvent_shell::~QIconDragEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QIconDragEvent::~QIconDragEvent()", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->destructed(typeid(QIconDragEvent));
}

void QIconDragEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QIconDragEvent_shell*>(ptr)->QIconDragEvent_shell::__shell()->tryDeleteShell(typeid(QIconDragEvent));
}

// emitting Virtual overrides (virtualFunctions)
QIconDragEvent* QIconDragEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QIconDragEvent::clone()const", QIconDragEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QIconDragEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QIconDragEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QIconDragEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QIconDragEvent_shell::__shell()->warnForMethod("QIconDragEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QIconDragEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QIconDragEvent::clone();
        }
    }else{
        return QIconDragEvent::clone();
    }
}

void QIconDragEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QIconDragEvent::", QIconDragEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QIconDragEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QIconDragEvent_shell::__shell()->warnForMethod("QIconDragEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QIconDragEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QIconDragEvent_access::__qt_assign_cref_QIconDragEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QIconDragEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QIconDragEvent>(__jni_env, other0);
    QIconDragEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QIconDragEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QIconDragEvent* __qt_return_value = QIconDragEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QIconDragEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QIconDragEvent()
void __qt_construct_QIconDragEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIconDragEvent()")
    Q_UNUSED(__java_arguments)
    QIconDragEvent *__qt_this = new(__qtjambi_ptr) QIconDragEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QIconDragEvent::QIconDragEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_initialize_1native__Lio_qt_gui_QIconDragEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIconDragEvent::QIconDragEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIconDragEvent, sizeof(QIconDragEvent_shell), typeid(QIconDragEvent), true, &deleter_QIconDragEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QIconDragEvent(QIconDragEvent)
void __qt_construct_QIconDragEvent_cref_QIconDragEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIconDragEvent(QIconDragEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QIconDragEvent& __qt_arg__1 = qtjambi_cast<const QIconDragEvent& >(__jni_env, arg__1);
    QIconDragEvent *__qt_this = new(__qtjambi_ptr) QIconDragEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QIconDragEvent::QIconDragEvent(QIconDragEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_initialize_1native__Lio_qt_gui_QIconDragEvent_2Lio_qt_gui_QIconDragEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIconDragEvent::QIconDragEvent(QIconDragEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIconDragEvent_cref_QIconDragEvent, sizeof(QIconDragEvent_shell), typeid(QIconDragEvent), true, &deleter_QIconDragEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QIconDragEvent_shell
void __qt_destruct_QIconDragEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QIconDragEvent")
    reinterpret_cast<QIconDragEvent_shell*>(ptr)->~QIconDragEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QIconDragEvent::operator=(QIconDragEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_assign_1native_1cref_1QIconDragEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QIconDragEvent *__qt_this = QtJambiAPI::objectFromNativeId<QIconDragEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QIconDragEvent::operator=(QIconDragEvent)", __qt_this)
        static_cast<QIconDragEvent_access*>(__qt_this)->__qt_assign_cref_QIconDragEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QIconDragEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QIconDragEvent *__qt_this = QtJambiAPI::objectFromNativeId<QIconDragEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QIconDragEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QIconDragEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QIconDragEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QIconDragEvent>("QIconDragEvent", "io/qt/gui/QIconDragEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QIconDragEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QIconDragEvent, {
        ConstructorInfo(&__qt_construct_QIconDragEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QIconDragEvent_cref_QIconDragEvent, "Lio/qt/gui/QIconDragEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QIconDragEvent);
    registerSizeOfShell(typeId, sizeof(QIconDragEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QIconDragEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
